{% load i18n sizeformat %}

<h3>Scaling Group Overview</h3>
<div class="info detail">
    <dl class="dl-horizontal">
        <!-- Name -->
        <dt title="{% trans 'Name' %}">{% trans "Name" %}</dt>
        <dd>{{ scaling_group.name|default:_("None") }}</dd>

        <!-- Description (conditional) -->
        {% if scaling_group.description %}
        <dt title="{% trans 'Description' %}">{% trans "Description" %}</dt>
        <dd>{{ scaling_group.name|default:_("None") }}</dd>
        {% endif %}

        <!-- Scaling Policy -->
        <dt title="{% trans 'Scaling Policy' %}">{% trans "Scaling Policy"%}
        <dd>{{ scaling_group.scaling_policy_id}}</dd>
    </dl>
</div>
