# Copyright 2015 A10 Networks
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from django.utils.translation import ugettext_lazy as _

from horizon import tabs
from horizon import workflows

import a10_horizon.dashboard.a10networks.a10appliances.tabs as p_tabs
import a10_horizon.dashboard.a10networks.a10appliances.workflows as p_workflows


class IndexView(tabs.TabbedTableView):
    tab_group_class = p_tabs.A10Tabs
    template_name = "appliances_tabs.html"

