{% extends 'base.html' %}
{% load i18n %}
{% load staticfiles %}

{% block title %}{% trans "Load Balancer" %}{% endblock %}
{% block page_header %}

{% endblock %}

{% block main %}
<div class="row">



  <div class="col-sm-12">
  {{ tab_group.render }}
  </div>
</div>
{% endblock %}
