<!-- Copyright (C) 2014-2015, A10 Networks Inc. All rights reserved. -->

<!-- Scaling Group Policy -->

{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}
{% block form_id %}updatealarm{% endblock %}

{% block form_action %}
{% url 'horizon:project:a10scaling:updatealarm' id=id %}
{% endblock %}

{% block modal-body-right %}
  <h3>{% trans "Description:" %}</h3>
  <p>{% trans "You may update the editable properties of the scaling alarm here." %}</p>

{% endblock %}
