
<!-- Copyright (C) 2014-2015, A10 Networks Inc. All rights reserved. -->

<!-- Scaling Group Policy -->
{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block modal-body-right %}
  <h3>{% trans "Description:" %}</h3>
  <p>{% trans "Creates a scaling action with specified parameters." %}</p>
{% endblock %}
