{% extends 'base.html' %}

{% block main %}
{% block title %}{% endblock %}

<div class="row">
  <div class="col-sm-12">
    {% include "group/_detail_overview.html" %}
    <hr />
    <h3>
        Scaling Group Workers
    </h3>
    <div id="a10scalinggroupmembertable">
      {{ a10scalinggroupmembertable_table.render }}
    </div>
  </div>
</div>
{% endblock %}
