# Copyright (C) 2014-2015, A10 Networks Inc. All rights reserved.

# http://legacy.python.org/dev/peps/pep-0440/#version-scheme
# Use the pep-0440 as a versioning guidline
# There are always four parts, although trailing parts 'may' be empty.
# Idealy the first 3 parts will always have a value
__version__ = "0.1.0"
__version_info__ = ('0', '1', '0')

# from a10_horizon.dashboard import base


# add_tab = base.add_tab
# post_hack = base.post_hack
